pub struct TransformRegistry { /* private fields */ }Expand description
A registry for managing transform configurations.
This struct provides a way to register and manage multiple transform configurations that can be applied to images in sequence.
Implementations
Sourceimpl TransformRegistry
impl TransformRegistry
Sourcepub fn new() -> TransformRegistry
pub fn new() -> TransformRegistry
Sourcepub fn add(&mut self, transform_type: TransformType, config: TransformConfig)
pub fn add(&mut self, transform_type: TransformType, config: TransformConfig)
Adds a transform to the registry.
Arguments
transform_type- The type of transform to add.config- The configuration for the transform.
Examples
use oar_ocr_core::core::config::transform::{TransformRegistry, TransformType, TransformConfig};
let mut registry = TransformRegistry::new();
registry.add(TransformType::ResizeImage, TransformConfig::ResizeImage {
width: Some(224),
height: Some(224),
shorter_side: None,
longer_side: None,
maintain_aspect_ratio: Some(false),
interpolation: None,
});
assert_eq!(registry.len(), 1);Sourcepub fn remove(&mut self, transform_type: &TransformType) -> usize
pub fn remove(&mut self, transform_type: &TransformType) -> usize
Sourcepub fn iter(&self) -> Iter<'_, (TransformType, TransformConfig)>
pub fn iter(&self) -> Iter<'_, (TransformType, TransformConfig)>
Gets an iterator over the transforms in the registry.
Returns
An iterator over tuples of (TransformType, TransformConfig).
Sourcepub fn iter_mut(&mut self) -> IterMut<'_, (TransformType, TransformConfig)>
pub fn iter_mut(&mut self) -> IterMut<'_, (TransformType, TransformConfig)>
Gets a mutable iterator over the transforms in the registry.
Returns
A mutable iterator over tuples of (TransformType, TransformConfig).
Sourcepub fn contains(&self, transform_type: &TransformType) -> bool
pub fn contains(&self, transform_type: &TransformType) -> bool
Sourcepub fn get_all(&self, transform_type: &TransformType) -> Vec<&TransformConfig>
pub fn get_all(&self, transform_type: &TransformType) -> Vec<&TransformConfig>
Sourcepub fn get_first(
&self,
transform_type: &TransformType,
) -> Option<&TransformConfig>
pub fn get_first( &self, transform_type: &TransformType, ) -> Option<&TransformConfig>