pub enum TensorOutput {
F32 {
shape: Vec<i64>,
data: Vec<f32>,
},
I64 {
shape: Vec<i64>,
data: Vec<i64>,
},
}Expand description
Generic tensor output supporting multiple data types.
This enum represents the raw output from an inference engine without making assumptions about the semantic meaning of the data. It’s the responsibility of the caller (model layer) to interpret and validate the output shape and type.
Variants
Implementations
Sourceimpl TensorOutput
impl TensorOutput
Sourcepub fn try_into_array2_f32(
self,
) -> Result<ArrayBase<OwnedRepr<f32>, Dim<[usize; 2]>>, OCRError>
pub fn try_into_array2_f32( self, ) -> Result<ArrayBase<OwnedRepr<f32>, Dim<[usize; 2]>>, OCRError>
Attempts to extract as a 2D f32 array.
Errors
Returns an error if:
- The tensor is not f32 type
- The tensor is not 2-dimensional
- The data length doesn’t match the shape
Sourcepub fn try_into_array3_f32(
self,
) -> Result<ArrayBase<OwnedRepr<f32>, Dim<[usize; 3]>>, OCRError>
pub fn try_into_array3_f32( self, ) -> Result<ArrayBase<OwnedRepr<f32>, Dim<[usize; 3]>>, OCRError>
Attempts to extract as a 3D f32 array.
Sourcepub fn try_into_array4_f32(
self,
) -> Result<ArrayBase<OwnedRepr<f32>, Dim<[usize; 4]>>, OCRError>
pub fn try_into_array4_f32( self, ) -> Result<ArrayBase<OwnedRepr<f32>, Dim<[usize; 4]>>, OCRError>
Attempts to extract as a 4D f32 array.
Sourcepub fn try_into_array_f32(
self,
) -> Result<ArrayBase<OwnedRepr<f32>, Dim<IxDynImpl>>, OCRError>
pub fn try_into_array_f32( self, ) -> Result<ArrayBase<OwnedRepr<f32>, Dim<IxDynImpl>>, OCRError>
Attempts to extract as a dynamic-dimensional f32 array.