pub struct CRNNModel { /* private fields */ }Expand description
Pure CRNN model implementation.
This model implements the CRNN architecture for text recognition.
Implementations
Sourceimpl CRNNModel
impl CRNNModel
Sourcepub fn new(
inference: OrtInfer,
resizer: OCRResize,
decoder: CTCLabelDecode,
) -> CRNNModel
pub fn new( inference: OrtInfer, resizer: OCRResize, decoder: CTCLabelDecode, ) -> CRNNModel
Creates a new CRNN model.
Sourcepub fn preprocess(
&self,
images: Vec<ImageBuffer<Rgb<u8>, Vec<u8>>>,
) -> Result<ArrayBase<OwnedRepr<f32>, Dim<[usize; 4]>>, OCRError>
pub fn preprocess( &self, images: Vec<ImageBuffer<Rgb<u8>, Vec<u8>>>, ) -> Result<ArrayBase<OwnedRepr<f32>, Dim<[usize; 4]>>, OCRError>
Sourcepub fn preprocess_refs(
&self,
images: &[&ImageBuffer<Rgb<u8>, Vec<u8>>],
) -> Result<ArrayBase<OwnedRepr<f32>, Dim<[usize; 4]>>, OCRError>
pub fn preprocess_refs( &self, images: &[&ImageBuffer<Rgb<u8>, Vec<u8>>], ) -> Result<ArrayBase<OwnedRepr<f32>, Dim<[usize; 4]>>, OCRError>
Preprocesses borrowed images for recognition without cloning their pixel buffers.
This is used by task adapters whose inputs are shared through Arc<RgbImage>.
The resized tensor owns all data needed by inference, so retaining ownership of
the source images during preprocessing is unnecessary.
Sourcepub fn infer(
&self,
batch_tensor: &ArrayBase<OwnedRepr<f32>, Dim<[usize; 4]>>,
) -> Result<ArrayBase<OwnedRepr<f32>, Dim<[usize; 3]>>, OCRError>
pub fn infer( &self, batch_tensor: &ArrayBase<OwnedRepr<f32>, Dim<[usize; 4]>>, ) -> Result<ArrayBase<OwnedRepr<f32>, Dim<[usize; 3]>>, OCRError>
Sourcepub fn postprocess<S>(
&self,
predictions: &ArrayBase<S, Dim<[usize; 3]>>,
return_positions: bool,
) -> CRNNModelOutput
pub fn postprocess<S>( &self, predictions: &ArrayBase<S, Dim<[usize; 3]>>, return_positions: bool, ) -> CRNNModelOutput
Sourcepub fn forward(
&self,
images: Vec<ImageBuffer<Rgb<u8>, Vec<u8>>>,
return_positions: bool,
) -> Result<CRNNModelOutput, OCRError>
pub fn forward( &self, images: Vec<ImageBuffer<Rgb<u8>, Vec<u8>>>, return_positions: bool, ) -> Result<CRNNModelOutput, OCRError>
Sourcepub fn forward_refs(
&self,
images: &[&ImageBuffer<Rgb<u8>, Vec<u8>>],
return_positions: bool,
) -> Result<CRNNModelOutput, OCRError>
pub fn forward_refs( &self, images: &[&ImageBuffer<Rgb<u8>, Vec<u8>>], return_positions: bool, ) -> Result<CRNNModelOutput, OCRError>
Runs recognition from borrowed images without copying their pixel buffers.