pub struct SLANetModelBuilder { /* private fields */ }Expand description
Builder for SLANet model.
Implementations
Sourceimpl SLANetModelBuilder
impl SLANetModelBuilder
Sourcepub fn new() -> SLANetModelBuilder
pub fn new() -> SLANetModelBuilder
Creates a new SLANet model builder.
Sourcepub fn input_size(self, size: (u32, u32)) -> SLANetModelBuilder
pub fn input_size(self, size: (u32, u32)) -> SLANetModelBuilder
Sets the input image size (height, width).
This is a convenience method that creates an InputShape with dynamic batch.
For more control, use input_shape() directly.
Sourcepub fn input_shape(self, shape: InputShape) -> SLANetModelBuilder
pub fn input_shape(self, shape: InputShape) -> SLANetModelBuilder
Sets the input shape directly.
If not set, the input shape will be parsed from the ONNX model.
Sourcepub fn with_ort_config(self, config: OrtSessionConfig) -> SLANetModelBuilder
pub fn with_ort_config(self, config: OrtSessionConfig) -> SLANetModelBuilder
Sets the ONNX Runtime session configuration.
Sourcepub fn build(self, model_path: &Path) -> Result<SLANetModel, OCRError>
pub fn build(self, model_path: &Path) -> Result<SLANetModel, OCRError>
Builds the SLANet model.
The input shape is determined in the following order:
- If explicitly set via
input_shape()orinput_size(), use that - Otherwise, parse from ONNX model metadata
- If ONNX has dynamic spatial dimensions, use default 512x512