Module uvdoc

Module uvdoc 

UVDoc Document Rectification Model

This module provides a pure implementation of the UVDoc model for document rectification. The model takes distorted document images and outputs rectified (flattened) versions.

Structs

UVDocModel
Pure UVDoc model implementation.
UVDocModelBuilder
Builder for UVDoc model.
UVDocModelOutput
Output from UVDoc model.
UVDocPreprocessConfig
Configuration for UVDoc model preprocessing.