pub struct OrtSessionConfig {
pub intra_threads: Option<usize>,
pub inter_threads: Option<usize>,
pub parallel_execution: Option<bool>,
pub optimization_level: Option<OrtGraphOptimizationLevel>,
pub execution_providers: Option<Vec<OrtExecutionProvider>>,
pub enable_mem_pattern: Option<bool>,
pub log_severity_level: Option<i32>,
pub log_verbosity_level: Option<i32>,
pub session_config_entries: Option<HashMap<String, String>>,
}Expand description
Configuration for ONNX Runtime sessions.
This struct contains various configuration options for ONNX Runtime sessions, including threading, memory management, and optimization settings.
Fields
intra_threads: Option<usize>Number of threads used to parallelize execution within nodes
inter_threads: Option<usize>Number of threads used to parallelize execution across nodes
parallel_execution: Option<bool>Enable parallel execution mode
optimization_level: Option<OrtGraphOptimizationLevel>Graph optimization level
execution_providers: Option<Vec<OrtExecutionProvider>>Execution providers in order of preference
enable_mem_pattern: Option<bool>Enable memory pattern optimization
log_severity_level: Option<i32>Log severity level (0=Verbose, 1=Info, 2=Warning, 3=Error, 4=Fatal)
log_verbosity_level: Option<i32>Log verbosity level
session_config_entries: Option<HashMap<String, String>>Session configuration entries (key-value pairs)
Implementations
Sourceimpl OrtSessionConfig
impl OrtSessionConfig
Sourcepub fn new() -> OrtSessionConfig
pub fn new() -> OrtSessionConfig
Creates a new OrtSessionConfig with default values.
Sourcepub fn with_intra_threads(self, threads: usize) -> OrtSessionConfig
pub fn with_intra_threads(self, threads: usize) -> OrtSessionConfig
Sourcepub fn with_inter_threads(self, threads: usize) -> OrtSessionConfig
pub fn with_inter_threads(self, threads: usize) -> OrtSessionConfig
Sourcepub fn with_parallel_execution(self, enabled: bool) -> OrtSessionConfig
pub fn with_parallel_execution(self, enabled: bool) -> OrtSessionConfig
Sourcepub fn with_optimization_level(
self,
level: OrtGraphOptimizationLevel,
) -> OrtSessionConfig
pub fn with_optimization_level( self, level: OrtGraphOptimizationLevel, ) -> OrtSessionConfig
Sourcepub fn with_execution_providers(
self,
providers: Vec<OrtExecutionProvider>,
) -> OrtSessionConfig
pub fn with_execution_providers( self, providers: Vec<OrtExecutionProvider>, ) -> OrtSessionConfig
Sourcepub fn add_execution_provider(
self,
provider: OrtExecutionProvider,
) -> OrtSessionConfig
pub fn add_execution_provider( self, provider: OrtExecutionProvider, ) -> OrtSessionConfig
Sourcepub fn with_memory_pattern(self, enable: bool) -> OrtSessionConfig
pub fn with_memory_pattern(self, enable: bool) -> OrtSessionConfig
Sourcepub fn with_log_severity_level(self, level: i32) -> OrtSessionConfig
pub fn with_log_severity_level(self, level: i32) -> OrtSessionConfig
Sourcepub fn with_log_verbosity_level(self, level: i32) -> OrtSessionConfig
pub fn with_log_verbosity_level(self, level: i32) -> OrtSessionConfig
Sourcepub fn add_config_entry<K, V>(self, key: K, value: V) -> OrtSessionConfig
pub fn add_config_entry<K, V>(self, key: K, value: V) -> OrtSessionConfig
Sourcepub fn get_intra_threads(&self) -> usize
pub fn get_intra_threads(&self) -> usize
Gets the effective number of intra-op threads.
Returns
The number of intra-op threads, or a default value if not set.
Sourcepub fn get_inter_threads(&self) -> usize
pub fn get_inter_threads(&self) -> usize
Gets the effective number of inter-op threads.
Returns
The number of inter-op threads, or a default value if not set.
Sourcepub fn get_optimization_level(&self) -> OrtGraphOptimizationLevel
pub fn get_optimization_level(&self) -> OrtGraphOptimizationLevel
Gets the effective graph optimization level.
Returns
The graph optimization level, or a default value if not set.
Sourcepub fn get_execution_providers(&self) -> Vec<OrtExecutionProvider>
pub fn get_execution_providers(&self) -> Vec<OrtExecutionProvider>
Gets the execution providers.
Returns
A reference to the execution providers, or a default CPU provider if not set.