IntoOwnedPrediction

Trait IntoOwnedPrediction 

pub trait IntoOwnedPrediction {
    type Out;

    // Required method
    fn into_owned_prediction(self) -> Self::Out;
}
Trait for converting a type into an owned prediction result.

This trait is used to convert a type into an owned prediction result.

Required Associated Types

type Out

The output type.

Required Methods

fn into_owned_prediction(self) -> Self::Out

Converts the type into an owned prediction result.

Returns

The owned prediction result.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> IntoOwnedPrediction for T

Implementation of IntoOwnedPrediction for types that implement IntoPrediction.

This implementation allows types that implement IntoPrediction to be converted into owned prediction results.