pub trait IntoOwnedPrediction {
type Out;
// Required method
fn into_owned_prediction(self) -> Self::Out;
}Expand description
Trait for converting a type into an owned prediction result.
This trait is used to convert a type into an owned prediction result.
Required Associated Types
Required Methods
Sourcefn into_owned_prediction(self) -> Self::Out
fn into_owned_prediction(self) -> Self::Out
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
Sourceimpl<T> IntoOwnedPrediction for T
Implementation of IntoOwnedPrediction for types that implement IntoPrediction.
impl<T> IntoOwnedPrediction for T
Implementation of IntoOwnedPrediction for types that implement IntoPrediction.
This implementation allows types that implement IntoPrediction to be converted into owned prediction results.