pub trait IntoPrediction {
type Out;
// Required method
fn into_prediction(self) -> Self::Out;
}Expand description
Trait for converting a type into a prediction result.
This trait is used to convert a type into a prediction result.
pub trait IntoPrediction {
type Out;
// Required method
fn into_prediction(self) -> Self::Out;
}Trait for converting a type into a prediction result.
This trait is used to convert a type into a prediction result.