pub trait IntoPrediction {
type Out;
// Required method
fn into_prediction(self) -> Self::Out;
}Expand description
Trait for converting a type into a prediction result.
This trait is used to convert a type into a prediction result.
Required Associated Types
Required Methods
Sourcefn into_prediction(self) -> Self::Out
fn into_prediction(self) -> Self::Out
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".