IntoPrediction

Trait IntoPrediction 

pub trait IntoPrediction {
    type Out;

    // Required method
    fn into_prediction(self) -> Self::Out;
}
Trait for converting a type into a prediction result.

This trait is used to convert a type into a prediction result.

Required Associated Types

type Out

The output type.

Required Methods

fn into_prediction(self) -> Self::Out

Converts the type into a prediction result.

Returns

The prediction result.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors