UVDoc Document Rectification Model
This module provides a pure implementation of the UVDoc model for document rectification. The model takes distorted document images and outputs rectified (flattened) versions.
Structs
- UVDoc
Model - Pure UVDoc model implementation.
- UVDoc
Model Builder - Builder for UVDoc model.
- UVDoc
Model Output - Output from UVDoc model.
- UVDoc
Preprocess Config - Configuration for UVDoc model preprocessing.